from gemini_framework.abstract.unit_module_abstract import UnitModuleAbstract
from gemini_model.pump.esp import ESP
import traceback


class CalculateTheoreticalOutletPressure(UnitModuleAbstract):
    """ Class of CalculateTheoreticalOutletPressure

    Class to calculate theoretical outlet pressure of ESP by
    adding theoretical calculated pump head to the measure inlet pressure

    theoretical pump head were calculated using
    esp_head_coefficient, flow and frequency
    """

    def __init__(self, unit):
        super().__init__(unit)

        self.model = ESP()

    def link(self):
        self.link_input(self.unit, 'measured', 'esp_inlet_pressure')
        self.link_input(self.unit, 'calculated', 'esp_theoretical_head')
        self.link_output(self.unit, 'calculated', 'esp_theoretical_outlet_pressure')

    def step(self, loop):
        try:
            self.loop = loop
            self.loop.start_time = self.get_output_last_data_time('esp_theoretical_outlet_pressure')
            self.loop.compute_n_simulation()

            time, esp_inlet = self.get_input_data('esp_inlet_pressure')
            time, esp_theoretical_head = self.get_input_data('esp_theoretical_head')

            esp_outlet = []
            time_calc = []
            for ii in range(1, self.loop.n_step + 1):
                time_calc.append(time[ii])
                if (esp_theoretical_head[ii] is None) or (esp_inlet[ii] is None):
                    esp_outlet.append(None)
                    continue

                esp_head = esp_theoretical_head[ii] + esp_inlet[ii]

                esp_outlet.append(esp_head)

            if time_calc:
                self.write_output_data('esp_theoretical_outlet_pressure', time_calc, esp_outlet)

        except Exception:
            self.logger.warn(
                "ERROR in module " + self.__class__.__name__ + " : " + traceback.format_exc())

    def update_model_parameter(self, timestamp):
        pass
